# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.manifest_extension_command import ManifestExtensionCommand

class TestManifestExtensionCommand(unittest.TestCase):
    """ManifestExtensionCommand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ManifestExtensionCommand:
        """Test ManifestExtensionCommand
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ManifestExtensionCommand`
        """
        model = ManifestExtensionCommand()
        if include_optional:
            return ManifestExtensionCommand(
                id = 'convert',
                on = picteus_ws_client.models.manifest_extension_command_on.ManifestExtensionCommandOn(
                    entity = null, 
                    with_tags = [
                        '0'
                        ], ),
                parameters = None,
                specifications = [
                    picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                        locale = 'en', 
                        label = 'Resize an image', 
                        description = 'Resizes an image given a format asked to the user.', )
                    ]
            )
        else:
            return ManifestExtensionCommand(
                id = 'convert',
                on = picteus_ws_client.models.manifest_extension_command_on.ManifestExtensionCommandOn(
                    entity = null, 
                    with_tags = [
                        '0'
                        ], ),
                specifications = [
                    picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                        locale = 'en', 
                        label = 'Resize an image', 
                        description = 'Resizes an image given a format asked to the user.', )
                    ],
        )
        """

    def testManifestExtensionCommand(self):
        """Test ManifestExtensionCommand"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
