# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.search_parameters import SearchParameters

class TestSearchParameters(unittest.TestCase):
    """SearchParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchParameters:
        """Test SearchParameters
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchParameters`
        """
        model = SearchParameters()
        if include_optional:
            return SearchParameters(
                filter = picteus_ws_client.models.search_filter.SearchFilter(
                    criteria = null, 
                    origin = null, 
                    sorting = null, ),
                collection_id = 123,
                range = picteus_ws_client.models.search_range.SearchRange(
                    take = 20, 
                    skip = 0, )
            )
        else:
            return SearchParameters(
        )
        """

    def testSearchParameters(self):
        """Test SearchParameters"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
