# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ImageFeatureType(str, Enum):
    """
    All the possible types for an image feature.
    """

    """
    allowed enum values
    """
    CAPTION = 'caption'
    DESCRIPTION = 'description'
    COMMENT = 'comment'
    ANNOTATION = 'annotation'
    METADATA = 'metadata'
    RECIPE = 'recipe'
    IDENTITY = 'identity'
    OTHER = 'other'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ImageFeatureType from a JSON string"""
        return cls(json.loads(json_str))


