# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.extension_api import ExtensionApi


class TestExtensionApi(unittest.TestCase):
    """ExtensionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ExtensionApi()

    def tearDown(self) -> None:
        pass

    def test_extension_activities(self) -> None:
        """Test case for extension_activities

        Indicates the extension activities
        """
        pass

    def test_extension_build(self) -> None:
        """Test case for extension_build

        Builds an extension
        """
        pass

    def test_extension_generate(self) -> None:
        """Test case for extension_generate

        Generates an extension
        """
        pass

    def test_extension_get(self) -> None:
        """Test case for extension_get

        Gets an extension
        """
        pass

    def test_extension_get_configuration(self) -> None:
        """Test case for extension_get_configuration

        Provides the extensions configuration
        """
        pass

    def test_extension_get_settings(self) -> None:
        """Test case for extension_get_settings

        Gets an extension settings
        """
        pass

    def test_extension_install(self) -> None:
        """Test case for extension_install

        Installs an extension
        """
        pass

    def test_extension_install_chrome_extension(self) -> None:
        """Test case for extension_install_chrome_extension

        Installs a Chrome extension
        """
        pass

    def test_extension_list(self) -> None:
        """Test case for extension_list

        Lists all extensions
        """
        pass

    def test_extension_pause_or_resume(self) -> None:
        """Test case for extension_pause_or_resume

        Pauses or resumes an extension
        """
        pass

    def test_extension_run_image_command(self) -> None:
        """Test case for extension_run_image_command

        Runs a command exposed by an extension, on images
        """
        pass

    def test_extension_run_process_command(self) -> None:
        """Test case for extension_run_process_command

        Runs a command exposed by an extension, on the process
        """
        pass

    def test_extension_set_settings(self) -> None:
        """Test case for extension_set_settings

        Sets an extension settings
        """
        pass

    def test_extension_synchronize(self) -> None:
        """Test case for extension_synchronize

        Synchronizes the images via an extension
        """
        pass

    def test_extension_uninstall(self) -> None:
        """Test case for extension_uninstall

        Uninstalls an extension
        """
        pass

    def test_extension_update(self) -> None:
        """Test case for extension_update

        Updates an extension
        """
        pass


if __name__ == '__main__':
    unittest.main()
