# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ManifestEvent(str, Enum):
    """
    The events which will trigger the instructions
    """

    """
    allowed enum values
    """
    PROCESS_DOT_STARTED = 'process.started'
    PROCESS_DOT_RUN_COMMAND = 'process.runCommand'
    EXTENSION_DOT_SETTINGS = 'extension.settings'
    IMAGE_DOT_CREATED = 'image.created'
    IMAGE_DOT_UPDATED = 'image.updated'
    IMAGE_DOT_DELETED = 'image.deleted'
    IMAGE_DOT_COMPUTE_FEATURES = 'image.computeFeatures'
    IMAGE_DOT_COMPUTE_EMBEDDINGS = 'image.computeEmbeddings'
    IMAGE_DOT_COMPUTE_TAGS = 'image.computeTags'
    IMAGE_DOT_RUN_COMMAND = 'image.runCommand'
    TEXT_DOT_COMPUTE_EMBEDDINGS = 'text.computeEmbeddings'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ManifestEvent from a JSON string"""
        return cls(json.loads(json_str))


