# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.api_secret import ApiSecret

class TestApiSecret(unittest.TestCase):
    """ApiSecret unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSecret:
        """Test ApiSecret
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSecret`
        """
        model = ApiSecret()
        if include_optional:
            return ApiSecret(
                id = 123,
                creation_date = 1761384334302,
                name = 'My entity name',
                comment = 'My comment on the entity',
                type = 'key',
                expiration_date = 1761385316688,
                scope = 'image:read,repository:read',
                value = 'Z&Q78&fqkPq'
            )
        else:
            return ApiSecret(
                id = 123,
                creation_date = 1761384334302,
                name = 'My entity name',
                type = 'key',
                value = 'Z&Q78&fqkPq',
        )
        """

    def testApiSecret(self):
        """Test ApiSecret"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
