# coding: utf-8

# flake8: noqa
"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from picteus_ws_client.models.api_secret import ApiSecret
from picteus_ws_client.models.api_secret_summary import ApiSecretSummary
from picteus_ws_client.models.api_secret_type import ApiSecretType
from picteus_ws_client.models.application_metadata import ApplicationMetadata
from picteus_ws_client.models.application_metadata_item import ApplicationMetadataItem
from picteus_ws_client.models.application_metadata_item_value import ApplicationMetadataItemValue
from picteus_ws_client.models.collection import Collection
from picteus_ws_client.models.command_entity import CommandEntity
from picteus_ws_client.models.computed_image_format import ComputedImageFormat
from picteus_ws_client.models.configuration_capability import ConfigurationCapability
from picteus_ws_client.models.configuration_extension_command import ConfigurationExtensionCommand
from picteus_ws_client.models.constants_registry import ConstantsRegistry
from picteus_ws_client.models.dates import Dates
from picteus_ws_client.models.extension import Extension
from picteus_ws_client.models.extension_activity import ExtensionActivity
from picteus_ws_client.models.extension_activity_kind import ExtensionActivityKind
from picteus_ws_client.models.extension_and_manual import ExtensionAndManual
from picteus_ws_client.models.extension_generation_options import ExtensionGenerationOptions
from picteus_ws_client.models.extension_image_embeddings import ExtensionImageEmbeddings
from picteus_ws_client.models.extension_image_feature import ExtensionImageFeature
from picteus_ws_client.models.extension_image_feature_name import ExtensionImageFeatureName
from picteus_ws_client.models.extension_image_features_attribute import ExtensionImageFeaturesAttribute
from picteus_ws_client.models.extension_image_tag import ExtensionImageTag
from picteus_ws_client.models.extension_image_tags_attribute import ExtensionImageTagsAttribute
from picteus_ws_client.models.extension_manual import ExtensionManual
from picteus_ws_client.models.extension_settings import ExtensionSettings
from picteus_ws_client.models.extension_status import ExtensionStatus
from picteus_ws_client.models.extensions_configuration import ExtensionsConfiguration
from picteus_ws_client.models.generation_recipe import GenerationRecipe
from picteus_ws_client.models.generation_recipe_prompt import GenerationRecipePrompt
from picteus_ws_client.models.image import Image
from picteus_ws_client.models.image_dimensions import ImageDimensions
from picteus_ws_client.models.image_distance import ImageDistance
from picteus_ws_client.models.image_embeddings import ImageEmbeddings
from picteus_ws_client.models.image_feature import ImageFeature
from picteus_ws_client.models.image_feature_format import ImageFeatureFormat
from picteus_ws_client.models.image_feature_null_value import ImageFeatureNullValue
from picteus_ws_client.models.image_feature_type import ImageFeatureType
from picteus_ws_client.models.image_feature_value import ImageFeatureValue
from picteus_ws_client.models.image_format import ImageFormat
from picteus_ws_client.models.image_media_url import ImageMediaUrl
from picteus_ws_client.models.image_metadata import ImageMetadata
from picteus_ws_client.models.image_resize_render import ImageResizeRender
from picteus_ws_client.models.image_summary import ImageSummary
from picteus_ws_client.models.instructions_prompt import InstructionsPrompt
from picteus_ws_client.models.manifest import Manifest
from picteus_ws_client.models.manifest_capability import ManifestCapability
from picteus_ws_client.models.manifest_capability_id import ManifestCapabilityId
from picteus_ws_client.models.manifest_event import ManifestEvent
from picteus_ws_client.models.manifest_execution import ManifestExecution
from picteus_ws_client.models.manifest_extension_command import ManifestExtensionCommand
from picteus_ws_client.models.manifest_extension_command_on import ManifestExtensionCommandOn
from picteus_ws_client.models.manifest_extension_command_specification import ManifestExtensionCommandSpecification
from picteus_ws_client.models.manifest_instructions import ManifestInstructions
from picteus_ws_client.models.manifest_interface_element import ManifestInterfaceElement
from picteus_ws_client.models.manifest_runtime import ManifestRuntime
from picteus_ws_client.models.manifest_runtime_environment import ManifestRuntimeEnvironment
from picteus_ws_client.models.manifest_throttling_policy import ManifestThrottlingPolicy
from picteus_ws_client.models.manifest_user_interface import ManifestUserInterface
from picteus_ws_client.models.prompt_kind import PromptKind
from picteus_ws_client.models.repository import Repository
from picteus_ws_client.models.repository_activity import RepositoryActivity
from picteus_ws_client.models.repository_activity_kind import RepositoryActivityKind
from picteus_ws_client.models.repository_location_type import RepositoryLocationType
from picteus_ws_client.models.repository_status import RepositoryStatus
from picteus_ws_client.models.search_criteria import SearchCriteria
from picteus_ws_client.models.search_feature_comparison_operator import SearchFeatureComparisonOperator
from picteus_ws_client.models.search_feature_condition import SearchFeatureCondition
from picteus_ws_client.models.search_feature_condition_value import SearchFeatureConditionValue
from picteus_ws_client.models.search_feature_logical_operator import SearchFeatureLogicalOperator
from picteus_ws_client.models.search_features import SearchFeatures
from picteus_ws_client.models.search_features_result import SearchFeaturesResult
from picteus_ws_client.models.search_filter import SearchFilter
from picteus_ws_client.models.search_filter_origin import SearchFilterOrigin
from picteus_ws_client.models.search_image_result import SearchImageResult
from picteus_ws_client.models.search_image_summary_result import SearchImageSummaryResult
from picteus_ws_client.models.search_images_origin import SearchImagesOrigin
from picteus_ws_client.models.search_keyword import SearchKeyword
from picteus_ws_client.models.search_origin_nature import SearchOriginNature
from picteus_ws_client.models.search_parameters import SearchParameters
from picteus_ws_client.models.search_properties import SearchProperties
from picteus_ws_client.models.search_property_range import SearchPropertyRange
from picteus_ws_client.models.search_range import SearchRange
from picteus_ws_client.models.search_repositories_origin import SearchRepositoriesOrigin
from picteus_ws_client.models.search_sorting import SearchSorting
from picteus_ws_client.models.search_sorting_property import SearchSortingProperty
from picteus_ws_client.models.search_tags import SearchTags
from picteus_ws_client.models.search_tags_result import SearchTagsResult
from picteus_ws_client.models.settings import Settings
from picteus_ws_client.models.software import Software
from picteus_ws_client.models.textual_prompt import TextualPrompt
from picteus_ws_client.models.user_interface_anchor import UserInterfaceAnchor

