# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.repository_api import RepositoryApi


class TestRepositoryApi(unittest.TestCase):
    """RepositoryApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RepositoryApi()

    def tearDown(self) -> None:
        pass

    def test_repository_activities(self) -> None:
        """Test case for repository_activities

        Indicates the repositories activities
        """
        pass

    def test_repository_create(self) -> None:
        """Test case for repository_create

        Creates a repository
        """
        pass

    def test_repository_delete(self) -> None:
        """Test case for repository_delete

        Deletes a repository
        """
        pass

    def test_repository_ensure(self) -> None:
        """Test case for repository_ensure

        Ensures a repository exists
        """
        pass

    def test_repository_get(self) -> None:
        """Test case for repository_get

        Gets a repository
        """
        pass

    def test_repository_get_feature_names(self) -> None:
        """Test case for repository_get_feature_names

        Gets all the feature names
        """
        pass

    def test_repository_get_image_by_url(self) -> None:
        """Test case for repository_get_image_by_url

        Gets an image from its URL
        """
        pass

    def test_repository_get_tags(self) -> None:
        """Test case for repository_get_tags

        Gets all the tags
        """
        pass

    def test_repository_list(self) -> None:
        """Test case for repository_list

        Lists repositories
        """
        pass

    def test_repository_rename_image(self) -> None:
        """Test case for repository_rename_image

        Renames an image
        """
        pass

    def test_repository_start_or_stop(self) -> None:
        """Test case for repository_start_or_stop

        Starts or stop the repositories
        """
        pass

    def test_repository_store_image(self) -> None:
        """Test case for repository_store_image

        Creates an image in the repository
        """
        pass

    def test_repository_synchronize(self) -> None:
        """Test case for repository_synchronize

        Synchronizes a repository
        """
        pass

    def test_repository_watch(self) -> None:
        """Test case for repository_watch

        Starts or stops watching a repository
        """
        pass


if __name__ == '__main__':
    unittest.main()
