# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.configuration_extension_command import ConfigurationExtensionCommand

class TestConfigurationExtensionCommand(unittest.TestCase):
    """ConfigurationExtensionCommand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConfigurationExtensionCommand:
        """Test ConfigurationExtensionCommand
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConfigurationExtensionCommand`
        """
        model = ConfigurationExtensionCommand()
        if include_optional:
            return ConfigurationExtensionCommand(
                extension_id = 'extension-id',
                command = picteus_ws_client.models.manifest_extension_command.ManifestExtensionCommand(
                    id = 'convert', 
                    on = null, 
                    parameters = picteus_ws_client.models.parameters.parameters(), 
                    specifications = [
                        picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                            locale = 'en', 
                            label = 'Resize an image', 
                            description = 'Resizes an image given a format asked to the user.', )
                        ], )
            )
        else:
            return ConfigurationExtensionCommand(
                extension_id = 'extension-id',
                command = picteus_ws_client.models.manifest_extension_command.ManifestExtensionCommand(
                    id = 'convert', 
                    on = null, 
                    parameters = picteus_ws_client.models.parameters.parameters(), 
                    specifications = [
                        picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                            locale = 'en', 
                            label = 'Resize an image', 
                            description = 'Resizes an image given a format asked to the user.', )
                        ], ),
        )
        """

    def testConfigurationExtensionCommand(self):
        """Test ConfigurationExtensionCommand"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
