# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.api_secret_api import ApiSecretApi


class TestApiSecretApi(unittest.TestCase):
    """ApiSecretApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApiSecretApi()

    def tearDown(self) -> None:
        pass

    def test_apisecret_create(self) -> None:
        """Test case for apisecret_create

        Creates an API secret
        """
        pass

    def test_apisecret_delete(self) -> None:
        """Test case for apisecret_delete

        Deletes an API secret
        """
        pass

    def test_apisecret_get(self) -> None:
        """Test case for apisecret_get

        Gets an API secret
        """
        pass

    def test_apisecret_list(self) -> None:
        """Test case for apisecret_list

        Lists all API secrets
        """
        pass


if __name__ == '__main__':
    unittest.main()
