# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.collection_api import CollectionApi


class TestCollectionApi(unittest.TestCase):
    """CollectionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CollectionApi()

    def tearDown(self) -> None:
        pass

    def test_collection_create(self) -> None:
        """Test case for collection_create

        Creates a collection
        """
        pass

    def test_collection_delete(self) -> None:
        """Test case for collection_delete

        Deletes collection
        """
        pass

    def test_collection_get(self) -> None:
        """Test case for collection_get

        Gets a collection
        """
        pass

    def test_collection_list(self) -> None:
        """Test case for collection_list

        Lists all collections
        """
        pass

    def test_collection_update(self) -> None:
        """Test case for collection_update

        Updates a collection
        """
        pass


if __name__ == '__main__':
    unittest.main()
