# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.user_interface_anchor import UserInterfaceAnchor

class TestUserInterfaceAnchor(unittest.TestCase):
    """UserInterfaceAnchor unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUserInterfaceAnchor(self):
        """Test UserInterfaceAnchor"""
        # inst = UserInterfaceAnchor()

if __name__ == '__main__':
    unittest.main()
