# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.settings_api import SettingsApi


class TestSettingsApi(unittest.TestCase):
    """SettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SettingsApi()

    def tearDown(self) -> None:
        pass

    def test_settings_get(self) -> None:
        """Test case for settings_get

        Gets all the settings
        """
        pass

    def test_settings_set(self) -> None:
        """Test case for settings_set

        Sets all the settings
        """
        pass


if __name__ == '__main__':
    unittest.main()
